@@ -20,12 +20,14 @@ pub struct MutableListArray<O: Offset, M: MutableArray> {
 }
 
 impl<O: Offset, M: MutableArray + Default> MutableListArray<O, M> {
+    /// Creates a new empty [`MutableListArray`].
     pub fn new() -> Self {
         let values = M::default();
         let data_type = ListArray::<O>::default_datatype(values.data_type().clone());
         Self::new_from(values, data_type, 0)
     }
 
+    /// Creates a new [`MutableListArray`] with a capacity.
     pub fn with_capacity(capacity: usize) -> Self {
         let values = M::default();
         let data_type = ListArray::<O>::default_datatype(values.data_type().clone());
@@ -40,6 +42,15 @@ impl<O: Offset, M: MutableArray + Default> MutableListArray<O, M> {
             validity: None,
         }
     }
+
+    /// Shrinks the capacity of the [`MutableListArray`] to fit its current length.
+    pub fn shrink_to_fit(&mut self) {
+        self.values.shrink_to_fit();
+        self.offsets.shrink_to_fit();
+        if let Some(validity) = &mut self.validity {
+            validity.shrink_to_fit()
+        }
+    }
 }
 
 impl<O: Offset, M: MutableArray + Default> Default for MutableListArray<O, M> {
@@ -79,6 +90,7 @@ where
     M: MutableArray + TryExtend<Option<T>>,
     I: IntoIterator<Item = Option<T>>,
 {
+    #[inline]
     fn try_push(&mut self, item: Option<I>) -> Result<()> {
         if let Some(items) = item {
             let values = self.mut_values();
@@ -92,6 +104,7 @@ where
 }
 
 impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
+    /// Creates a new [`MutableListArray`] from a [`MutableArray`] and capacity.
     pub fn new_from(values: M, data_type: DataType, capacity: usize) -> Self {
         let mut offsets = MutableBuffer::<O>::with_capacity(capacity + 1);
         offsets.push(O::default());
@@ -105,6 +118,7 @@ impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
         }
     }
 
+    /// Creates a new [`MutableListArray`] from a [`MutableArray`].
     pub fn new_with_field(values: M, name: &str, nullable: bool) -> Self {
         let field = Box::new(Field::new(name, values.data_type().clone(), nullable));
         let data_type = if O::is_large() {
@@ -115,12 +129,14 @@ impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
         Self::new_from(values, data_type, 0)
     }
 
+    /// Creates a new [`MutableListArray`] from a [`MutableArray`] and capacity.
     pub fn new_with_capacity(values: M, capacity: usize) -> Self {
         let data_type = ListArray::<O>::default_datatype(values.data_type().clone());
         Self::new_from(values, data_type, capacity)
     }
 
-    pub fn try_push_valid(&mut self) -> Result<()> {
+    #[inline]
+    fn try_push_valid(&mut self) -> Result<()> {
         let size = self.values.len();
         let size = O::from_usize(size).ok_or(ArrowError::KeyOverflowError)?; // todo: make this error
         assert!(size >= *self.offsets.last().unwrap());
@@ -132,6 +148,7 @@ impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
         Ok(())
     }
 
+    #[inline]
     fn push_null(&mut self) {
         self.offsets.push(self.last_offset());
         match &mut self.validity {
@@ -140,10 +157,12 @@ impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
         }
     }
 
+    /// The values
     pub fn mut_values(&mut self) -> &mut M {
         &mut self.values
     }
 
+    /// The values
     pub fn values(&self) -> &M {
         &self.values
     }
@@ -154,11 +173,12 @@ impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
     }
 
     fn init_validity(&mut self) {
-        self.validity = Some(MutableBitmap::from_trusted_len_iter(
-            std::iter::repeat(true)
-                .take(self.offsets.len() - 1 - 1)
-                .chain(std::iter::once(false)),
-        ))
+        let len = self.offsets.len() - 1;
+
+        let mut validity = MutableBitmap::new();
+        validity.extend_constant(len, true);
+        validity.set(len - 1, false);
+        self.validity = Some(validity)
     }
 
     /// Converts itself into an [`Array`].
@@ -168,13 +188,22 @@ impl<O: Offset, M: MutableArray> MutableListArray<O, M> {
     }
 }
 
-impl<O: Offset, M: MutableArray + 'static> MutableArray for MutableListArray<O, M> {
+impl<O: Offset, M: MutableArray + Default + 'static> MutableArray for MutableListArray<O, M> {
     fn len(&self) -> usize {
         self.offsets.len() - 1
     }
 
-    fn validity(&self) -> &Option<MutableBitmap> {
-        &self.validity
+    fn validity(&self) -> Option<&MutableBitmap> {
+        self.validity.as_ref()
+    }
+
+    fn as_box(&mut self) -> Box<dyn Array> {
+        Box::new(ListArray::from_data(
+            self.data_type.clone(),
+            std::mem::take(&mut self.offsets).into(),
+            self.values.as_arc(),
+            std::mem::take(&mut self.validity).map(|x| x.into()),
+        ))
     }
 
     fn as_arc(&mut self) -> Arc<dyn Array> {
@@ -198,7 +227,11 @@ impl<O: Offset, M: MutableArray + 'static> MutableArray for MutableListArray<O,
         self
     }
 
+    #[inline]
     fn push_null(&mut self) {
         self.push_null()
     }
+    fn shrink_to_fit(&mut self) {
+        self.shrink_to_fit();
+    }
 }
