@@ -1,18 +1,22 @@
-//! fixed-length and immutable containers with optional values
+#![deny(missing_docs)]
+//! Contains the [`Array`] and [`MutableArray`] trait objects declaring arrays,
+//! as well as concrete arrays (such as [`Utf8Array`] and [`MutableUtf8Array`]).
+//!
+//! Fixed-length containers with optional values
 //! that are layed in memory according to the Arrow specification.
 //! Each array type has its own `struct`. The following are the main array types:
-//! * [`PrimitiveArray`], an array of values with a fixed length such as integers, floats, etc.
-//! * [`BooleanArray`], an array of boolean values (stored as a bitmap)
-//! * [`Utf8Array`], an array of utf8 values
-//! * [`BinaryArray`], an array of binary values
-//! * [`ListArray`], an array of arrays (e.g. `[[1, 2], None, [], [None]]`)
+//! * [`PrimitiveArray`] and [`MutablePrimitiveArray`], an array of values with a fixed length such as integers, floats, etc.
+//! * [`BooleanArray`] and [`MutableBooleanArray`], an array of boolean values (stored as a bitmap)
+//! * [`Utf8Array`] and [`MutableUtf8Array`], an array of variable length utf8 values
+//! * [`BinaryArray`] and [`MutableBinaryArray`], an array of opaque variable length values
+//! * [`ListArray`] and [`MutableListArray`], an array of arrays (e.g. `[[1, 2], None, [], [None]]`)
 //! * [`StructArray`], an array of arrays identified by a string (e.g. `{"a": [1, 2], "b": [true, false]}`)
-//! All arrays implement the trait [`Array`] and are often trait objects that can be downcasted
-//! to a concrete struct based on [`DataType`] available from [`Array::data_type`].
-//! Arrays share memory via [`crate::buffer::Buffer`] and thus cloning and slicing them `O(1)`.
+//! All immutable arrays implement the trait object [`Array`] and that can be downcasted
+//! to a concrete struct based on [`PhysicalType`](crate::datatypes::PhysicalType) available from [`Array::data_type`].
+//! All immutable arrays are backed by [`Buffer`](crate::buffer::Buffer) and thus cloning and slicing them is `O(1)`.
 //!
-//! This module also contains the mutable counterparts of arrays, that are neither clonable nor slicable, but that
-//! can be operated in-place, such as [`MutablePrimitiveArray`] and [`MutableUtf8Array`].
+//! Most arrays contain a [`MutableArray`] counterpart that is neither clonable nor slicable, but
+//! can be operated in-place.
 use std::any::Any;
 use std::fmt::Display;
 
@@ -45,10 +49,9 @@ pub trait Array: std::fmt::Debug + Send + Sync {
     /// The validity of the [`Array`]: every array has an optional [`Bitmap`] that, when available
     /// specifies whether the array slot is valid or not (null).
     /// When the validity is [`None`], all slots are valid.
-    fn validity(&self) -> &Option<Bitmap>;
+    fn validity(&self) -> Option<&Bitmap>;
 
-    /// The number of null slots on this [`Array`]. This is usually used to branch
-    /// implementations to cases where optimizations can be made.
+    /// The number of null slots on this [`Array`].
     /// # Implementation
     /// This is `O(1)`.
     #[inline]
@@ -89,6 +92,14 @@ pub trait Array: std::fmt::Debug + Send + Sync {
     /// This function panics iff `offset + length >= self.len()`.
     fn slice(&self, offset: usize, length: usize) -> Box<dyn Array>;
 
+    /// Slices the [`Array`], returning a new `Box<dyn Array>`.
+    /// # Implementation
+    /// This operation is `O(1)` over `len`, as it amounts to increase two ref counts
+    /// and moving the struct to the heap.
+    /// # Safety
+    /// The caller must ensure that `offset + length <=| self.len()`
+    unsafe fn slice_unchecked(&self, offset: usize, length: usize) -> Box<dyn Array>;
+
     /// Sets the validity bitmap on this [`Array`].
     /// # Panic
     /// This function panics iff `validity.len() < self.len()`.
@@ -112,10 +123,18 @@ pub trait MutableArray: std::fmt::Debug {
     }
 
     /// The optional validity of the array.
-    fn validity(&self) -> &Option<MutableBitmap>;
+    fn validity(&self) -> Option<&MutableBitmap>;
 
-    /// Convert itself to an (immutable) [`Array`].
-    fn as_arc(&mut self) -> Arc<dyn Array>;
+    /// Convert itself to an (immutable) ['Array'].
+    fn as_box(&mut self) -> Box<dyn Array>;
+
+    /// Convert itself to an (immutable) atomically reference counted [`Array`].
+    // This provided implementation has an extra allocation as it first
+    // boxes `self`, then converts the box into an `Arc`. Implementors may wish
+    // to avoid an allocation by skipping the box completely.
+    fn as_arc(&mut self) -> Arc<dyn Array> {
+        self.as_box().into()
+    }
 
     /// Convert to `Any`, to enable dynamic casting.
     fn as_any(&self) -> &dyn Any;
@@ -136,6 +155,9 @@ pub trait MutableArray: std::fmt::Debug {
             .map(|x| x.get(index))
             .unwrap_or(true)
     }
+
+    /// Shrink the array to fit its length.
+    fn shrink_to_fit(&mut self);
 }
 
 macro_rules! general_dyn {
@@ -233,6 +255,7 @@ impl Display for dyn Array {
                     fmt_dyn!(self, DictionaryArray::<$T>, f)
                 })
             }
+            Map => todo!(),
         }
     }
 }
@@ -256,6 +279,7 @@ pub fn new_empty_array(data_type: DataType) -> Box<dyn Array> {
         FixedSizeList => Box::new(FixedSizeListArray::new_empty(data_type)),
         Struct => Box::new(StructArray::new_empty(data_type)),
         Union => Box::new(UnionArray::new_empty(data_type)),
+        Map => Box::new(MapArray::new_empty(data_type)),
         Dictionary(key_type) => {
             with_match_physical_dictionary_key_type!(key_type, |$T| {
                 Box::new(DictionaryArray::<$T>::new_empty(data_type))
@@ -285,6 +309,7 @@ pub fn new_null_array(data_type: DataType, length: usize) -> Box<dyn Array> {
         FixedSizeList => Box::new(FixedSizeListArray::new_null(data_type, length)),
         Struct => Box::new(StructArray::new_null(data_type, length)),
         Union => Box::new(UnionArray::new_null(data_type, length)),
+        Map => Box::new(MapArray::new_null(data_type, length)),
         Dictionary(key_type) => {
             with_match_physical_dictionary_key_type!(key_type, |$T| {
                 Box::new(DictionaryArray::<$T>::new_null(data_type, length))
@@ -322,6 +347,7 @@ pub fn clone(array: &dyn Array) -> Box<dyn Array> {
         FixedSizeList => clone_dyn!(array, FixedSizeListArray),
         Struct => clone_dyn!(array, StructArray),
         Union => clone_dyn!(array, UnionArray),
+        Map => clone_dyn!(array, MapArray),
         Dictionary(key_type) => {
             with_match_physical_dictionary_key_type!(key_type, |$T| {
                 clone_dyn!(array, DictionaryArray::<$T>)
@@ -337,6 +363,7 @@ mod display;
 mod fixed_size_binary;
 mod fixed_size_list;
 mod list;
+mod map;
 mod null;
 mod primitive;
 mod specification;
@@ -358,6 +385,7 @@ pub use dictionary::{DictionaryArray, DictionaryKey, MutableDictionaryArray};
 pub use fixed_size_binary::{FixedSizeBinaryArray, MutableFixedSizeBinaryArray};
 pub use fixed_size_list::{FixedSizeListArray, MutableFixedSizeListArray};
 pub use list::{ListArray, MutableListArray};
+pub use map::MapArray;
 pub use null::NullArray;
 pub use primitive::*;
 pub use specification::Offset;
@@ -427,7 +455,9 @@ fn display_fmt<T: std::fmt::Display, I: IntoIterator<Item = Option<T>>>(
 
 /// Trait that list arrays implement for the purposes of DRY.
 pub trait IterableListArray: Array {
-    fn value(&self, i: usize) -> Box<dyn Array>;
+    /// # Safety
+    /// The caller must ensure that `i < self.len()`
+    unsafe fn value_unchecked(&self, i: usize) -> Box<dyn Array>;
 }
 
 /// Trait that [`BinaryArray`] and [`Utf8Array`] implement for the purposes of DRY.
