@@ -18,15 +18,16 @@ pub use mutable::*;
 
 /// A [`PrimitiveArray`] is arrow's equivalent to `Vec<Option<T: NativeType>>`, i.e.
 /// an array designed for highly performant operations on optionally nullable slots,
-/// backed by a physical type of a physical byte-width, such as `i32` or `f64`.
+/// backed by a physical type of a fixed byte-width, such as `i32` or `f64`.
 /// The size of this struct is `O(1)` as all data is stored behind an [`std::sync::Arc`].
 /// # Example
 /// ```
-/// use arrow2::array::PrimitiveArray;
+/// use arrow2::array::{PrimitiveArray, Array};
+/// use arrow2::bitmap::Bitmap;
 /// # fn main() {
-/// let array = PrimitiveArray::<i32>::from([Some(1), None, Some(2)]);
-/// assert_eq!(array.value(0), 1);
-/// assert_eq!(array.values().as_slice(), &[1, 0, 2]);
+/// let array = PrimitiveArray::from([Some(1), None, Some(10)]);
+/// assert_eq!(array.values().as_slice(), &[1, 0, 10]);
+/// assert_eq!(array.validity(), Some(&Bitmap::from([true, false, true])));
 /// # }
 /// ```
 #[derive(Debug, Clone)]
@@ -85,17 +86,34 @@ impl<T: NativeType> PrimitiveArray<T> {
     /// This function panics iff `offset + length >= self.len()`.
     #[inline]
     pub fn slice(&self, offset: usize, length: usize) -> Self {
-        let validity = self.validity.clone().map(|x| x.slice(offset, length));
+        assert!(
+            offset + length <= self.len(),
+            "offset + length may not exceed length of array"
+        );
+        unsafe { self.slice_unchecked(offset, length) }
+    }
+
+    /// Returns a slice of this [`PrimitiveArray`].
+    /// # Implementation
+    /// This operation is `O(1)` as it amounts to increase two ref counts.
+    /// # Safety
+    /// The caller must ensure that `offset + length <= self.len()`.
+    #[inline]
+    pub unsafe fn slice_unchecked(&self, offset: usize, length: usize) -> Self {
+        let validity = self
+            .validity
+            .clone()
+            .map(|x| x.slice_unchecked(offset, length));
         Self {
             data_type: self.data_type.clone(),
-            values: self.values.clone().slice(offset, length),
+            values: self.values.clone().slice_unchecked(offset, length),
             validity,
             offset: self.offset + offset,
         }
     }
 
     /// Sets the validity bitmap on this [`PrimitiveArray`].
-    /// # Panic
+    /// # Panics
     /// This function panics iff `validity.len() != self.len()`.
     pub fn with_validity(&self, validity: Option<Bitmap>) -> Self {
         if matches!(&validity, Some(bitmap) if bitmap.len() != self.len()) {
@@ -106,21 +124,28 @@ impl<T: NativeType> PrimitiveArray<T> {
         arr
     }
 
+    /// The optional validity.
+    #[inline]
+    pub fn validity(&self) -> Option<&Bitmap> {
+        self.validity.as_ref()
+    }
+
     /// The values [`Buffer`].
+    /// Values on null slots are undetermined (they can be anything).
     #[inline]
     pub fn values(&self) -> &Buffer<T> {
         &self.values
     }
 
-    /// Safe method to retrieve the value at slot `i`.
-    /// Equivalent to `self.values()[i]`.
+    /// Returns the value at slot `i`. Equivalent to `self.values()[i]`.
+    /// The value on null slots is undetermined (it can be anything).
     #[inline]
     pub fn value(&self, i: usize) -> T {
         self.values()[i]
     }
 
-    /// Returns the element at index `i` as `T`
-    ///
+    /// Returns the element at index `i` as `T`.
+    /// The value on null slots is undetermined (it can be anything).
     /// # Safety
     /// Caller must be sure that `i < self.len()`
     #[inline]
@@ -167,13 +192,16 @@ impl<T: NativeType> Array for PrimitiveArray<T> {
         &self.data_type
     }
 
-    fn validity(&self) -> &Option<Bitmap> {
-        &self.validity
+    fn validity(&self) -> Option<&Bitmap> {
+        self.validity.as_ref()
     }
 
     fn slice(&self, offset: usize, length: usize) -> Box<dyn Array> {
         Box::new(self.slice(offset, length))
     }
+    unsafe fn slice_unchecked(&self, offset: usize, length: usize) -> Box<dyn Array> {
+        Box::new(self.slice_unchecked(offset, length))
+    }
     fn with_validity(&self, validity: Option<Bitmap>) -> Box<dyn Array> {
         Box::new(self.with_validity(validity))
     }
