@@ -1,19 +1,4 @@
-// Licensed to the Apache Software Foundation (ASF) under one
-// or more contributor license agreements.  See the NOTICE file
-// distributed with this work for additional information
-// regarding copyright ownership.  The ASF licenses this file
-// to you under the Apache License, Version 2.0 (the
-// "License"); you may not use this file except in compliance
-// with the License.  You may obtain a copy of the License at
-//
-//   http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing,
-// software distributed under the License is distributed on an
-// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied.  See the License for the
-// specific language governing permissions and limitations
-// under the License.
+//! Defines different casting operators such as [`cast`] or [`primitive_to_binary`].
 
 use crate::{
     array::*,
@@ -294,7 +279,7 @@ fn cast_list<O: Offset>(
         to_type.clone(),
         array.offsets().clone(),
         new_values,
-        array.validity().clone(),
+        array.validity().cloned(),
     ))
 }
 
@@ -307,7 +292,7 @@ fn cast_list_to_large_list(array: &ListArray<i32>, to_type: &DataType) -> ListAr
         to_type.clone(),
         offets,
         array.values().clone(),
-        array.validity().clone(),
+        array.validity().cloned(),
     )
 }
 
@@ -320,7 +305,7 @@ fn cast_large_to_list(array: &ListArray<i64>, to_type: &DataType) -> ListArray<i
         to_type.clone(),
         offets,
         array.values().clone(),
-        array.validity().clone(),
+        array.validity().cloned(),
     )
 }
 
@@ -538,7 +523,7 @@ fn cast_with_options(
                 // perf todo: the offsets are equal; we can speed-up this
                 let iter = array
                     .iter()
-                    .map(|x| x.and_then(|x| std::str::from_utf8(x).ok()));
+                    .map(|x| x.and_then(|x| simdutf8::basic::from_utf8(x).ok()));
 
                 let array = Utf8Array::<i32>::from_trusted_len_iter(iter);
                 Ok(Box::new(array))
@@ -574,7 +559,7 @@ fn cast_with_options(
                 // perf todo: the offsets are equal; we can speed-up this
                 let iter = array
                     .iter()
-                    .map(|x| x.and_then(|x| std::str::from_utf8(x).ok()));
+                    .map(|x| x.and_then(|x| simdutf8::basic::from_utf8(x).ok()));
 
                 let array = Utf8Array::<i64>::from_trusted_len_iter(iter);
                 Ok(Box::new(array))
