@@ -1,19 +1,4 @@
-// Licensed to the Apache Software Foundation (ASF) under one
-// or more contributor license agreements.  See the NOTICE file
-// distributed with this work for additional information
-// regarding copyright ownership.  The ASF licenses this file
-// to you under the Apache License, Version 2.0 (the
-// "License"); you may not use this file except in compliance
-// with the License.  You may obtain a copy of the License at
-//
-//   http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing,
-// software distributed under the License is distributed on an
-// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-// KIND, either express or implied.  See the License for the
-// specific language governing permissions and limitations
-// under the License.
+//! Declares the [`contains`] operator
 
 use crate::types::NativeType;
 use crate::{
@@ -141,6 +126,7 @@ macro_rules! primitive {
     }};
 }
 
+/// Returns whether each element in `values` is in each element from `list`
 pub fn contains(list: &dyn Array, values: &dyn Array) -> Result<BooleanArray> {
     let list_data_type = list.data_type();
     let values_data_type = values.data_type();
@@ -212,67 +198,3 @@ pub fn contains(list: &dyn Array, values: &dyn Array) -> Result<BooleanArray> {
         ))),
     }
 }
-
-// disable wrapping inside literal vectors used for test data and assertions
-#[rustfmt::skip::macros(vec)]
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    use crate::array::*;
-
-    // Expected behaviour:
-    // contains([1, 2, null], 1) = true
-    // contains([1, 2, null], 3) = false
-    // contains([1, 2, null], null) = null
-    // contains(null, 1) = null
-    #[test]
-    fn test_contains() {
-        let data = vec![
-            Some(vec![Some(1), Some(2), None]),
-            Some(vec![Some(1), Some(2), None]),
-            Some(vec![Some(1), Some(2), None]),
-            None,
-        ];
-        let values = Int32Array::from(&[Some(1), Some(3), None, Some(1)]);
-        let expected = BooleanArray::from(vec![
-            Some(true),
-            Some(false),
-            None,
-            None
-        ]);
-
-        let mut a = MutableListArray::<i32, MutablePrimitiveArray<i32>>::new();
-        a.try_extend(data).unwrap();
-        let a: ListArray<i32> = a.into();
-
-        let result = contains(&a, &values).unwrap();
-
-        assert_eq!(result, expected);
-    }
-
-    #[test]
-    fn test_contains_binary() {
-        let data = vec![
-            Some(vec![Some(b"a"), Some(b"b"), None]),
-            Some(vec![Some(b"a"), Some(b"b"), None]),
-            Some(vec![Some(b"a"), Some(b"b"), None]),
-            None,
-        ];
-        let values = BinaryArray::<i32>::from(&[Some(b"a"), Some(b"c"), None, Some(b"a")]);
-        let expected = BooleanArray::from(vec![
-            Some(true),
-            Some(false),
-            None,
-            None
-        ]);
-
-        let mut a = MutableListArray::<i32, MutableBinaryArray<i32>>::new();
-        a.try_extend(data).unwrap();
-        let a: ListArray<i32> = a.into();
-
-        let result = contains(&a, &values).unwrap();
-
-        assert_eq!(result, expected);
-    }
-}
