@@ -1,4 +1,5 @@
-//! Metadata declarations such as [`DataType`], [`Field`] and [`Schema`].
+#![deny(missing_docs)]
+//! Contains all metadata, such as [`PhysicalType`], [`DataType`], [`Field`] and [`Schema`].
 mod field;
 mod physical_type;
 mod schema;
@@ -11,8 +12,8 @@ pub(crate) use field::{get_extension, Extension, Metadata};
 
 /// The set of supported logical types.
 /// Each variant uniquely identifies a logical type, which define specific semantics to the data (e.g. how it should be represented).
-/// A [`DataType`] has an unique corresponding [`PhysicalType`], obtained via [`DataType::to_physical_type`],
-/// which uniquely identifies an in-memory representation of data.
+/// Each variant has a corresponding [`PhysicalType`], obtained via [`DataType::to_physical_type`],
+/// which declares the in-memory representation of data.
 /// The [`DataType::Extension`] is special in that it augments a [`DataType`] with metadata to support custom types.
 /// Use `to_logical_type` to desugar such type and return its correspoding logical type.
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
@@ -93,6 +94,32 @@ pub enum DataType {
     /// A nested datatype that can represent slots of differing types.
     /// Third argument represents sparsness
     Union(Vec<Field>, Option<Vec<i32>>, bool),
+    /// A nested type that is represented as
+    ///
+    /// List<entries: Struct<key: K, value: V>>
+    ///
+    /// In this layout, the keys and values are each respectively contiguous. We do
+    /// not constrain the key and value types, so the application is responsible
+    /// for ensuring that the keys are hashable and unique. Whether the keys are sorted
+    /// may be set in the metadata for this field.
+    ///
+    /// In a field with Map type, the field has a child Struct field, which then
+    /// has two children: key type and the second the value type. The names of the
+    /// child fields may be respectively "entries", "key", and "value", but this is
+    /// not enforced.
+    ///
+    /// Map
+    /// ```text
+    ///   - child[0] entries: Struct
+    ///     - child[0] key: K
+    ///     - child[1] value: V
+    /// ```
+    /// Neither the "entries" field nor the "key" field may be nullable.
+    ///
+    /// The metadata is structured so that Arrow systems without special handling
+    /// for Map can make Map an alias for List. The "layout" attribute for the Map
+    /// field must have the same contents as a List.
+    Map(Box<Field>, bool),
     /// A dictionary encoded array (`key_type`, `value_type`), where
     /// each array element is an index of `key_type` into an
     /// associated dictionary of `value_type`.
@@ -119,7 +146,7 @@ impl std::fmt::Display for DataType {
     }
 }
 
-/// Time units defined in Arrow.
+/// The time units defined in Arrow.
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
 pub enum TimeUnit {
     /// Time in seconds.
@@ -210,6 +237,7 @@ impl DataType {
             LargeList(_) => PhysicalType::LargeList,
             Struct(_) => PhysicalType::Struct,
             Union(_, _, _) => PhysicalType::Union,
+            Map(_, _) => PhysicalType::Map,
             Dictionary(key, _) => PhysicalType::Dictionary(to_dictionary_index_type(key.as_ref())),
             Extension(_, key, _) => key.to_physical_type(),
         }
