@@ -37,9 +37,9 @@ use crate::datatypes::*;
 use crate::error::{ArrowError, Result};
 use crate::record_batch::RecordBatch;
 
-pub struct FileWriter<'a, W: Write> {
+pub struct FileWriter<W: Write> {
     /// The object to write to
-    writer: &'a mut W,
+    writer: W,
     /// IPC write options
     write_options: IpcWriteOptions,
     /// A reference to the schema, used in validating record batches
@@ -56,16 +56,16 @@ pub struct FileWriter<'a, W: Write> {
     dictionary_tracker: DictionaryTracker,
 }
 
-impl<'a, W: Write> FileWriter<'a, W> {
+impl<W: Write> FileWriter<W> {
     /// Try create a new writer, with the schema written as part of the header
-    pub fn try_new(writer: &'a mut W, schema: &Schema) -> Result<Self> {
+    pub fn try_new(writer: W, schema: &Schema) -> Result<Self> {
         let write_options = IpcWriteOptions::default();
         Self::try_new_with_options(writer, schema, write_options)
     }
 
     /// Try create a new writer with IpcWriteOptions
     pub fn try_new_with_options(
-        writer: &'a mut W,
+        mut writer: W,
         schema: &Schema,
         write_options: IpcWriteOptions,
     ) -> Result<Self> {
@@ -78,7 +78,7 @@ impl<'a, W: Write> FileWriter<'a, W> {
             ipc_message: schema_to_bytes(schema, *write_options.metadata_version()),
             arrow_data: vec![],
         };
-        let (meta, data) = write_message(writer, encoded_message, &write_options)?;
+        let (meta, data) = write_message(&mut writer, encoded_message, &write_options)?;
         Ok(Self {
             writer,
             write_options,
@@ -91,6 +91,10 @@ impl<'a, W: Write> FileWriter<'a, W> {
         })
     }
 
+    pub fn into_inner(self) -> W {
+        self.writer
+    }
+
     /// Write a record batch to the file
     pub fn write(&mut self, batch: &RecordBatch) -> Result<()> {
         if self.finished {
@@ -153,12 +157,3 @@ impl<'a, W: Write> FileWriter<'a, W> {
         Ok(())
     }
 }
-
-/// Finish the file if it is not 'finished' when it goes out of scope
-impl<'a, W: Write> Drop for FileWriter<'a, W> {
-    fn drop(&mut self) {
-        if !self.finished {
-            self.finish().unwrap();
-        }
-    }
-}
