@@ -1,8 +1,5 @@
 //! APIs to read from Parquet format.
-use std::{
-    io::{Read, Seek},
-    sync::Arc,
-};
+use std::{convert::TryInto, io::{Read, Seek}, sync::Arc};
 
 use futures::{AsyncRead, AsyncSeek, Stream};
 pub use parquet2::{
@@ -21,11 +18,7 @@ pub use parquet2::{
     types::int96_to_i64_ns,
 };
 
-use crate::{
-    array::{Array, DictionaryKey},
-    datatypes::{DataType, IntervalUnit, TimeUnit},
-    error::{ArrowError, Result},
-};
+use crate::{array::{Array, DictionaryKey, PrimitiveArray}, datatypes::{DataType, IntervalUnit, TimeUnit}, error::{ArrowError, Result}};
 
 mod binary;
 mod boolean;
@@ -38,7 +31,8 @@ pub mod statistics;
 mod utils;
 
 pub use record_batch::RecordReader;
-pub use schema::{get_schema, is_type_nullable, FileMetaData};
+pub(crate) use schema::is_type_nullable;
+pub use schema::{get_schema, FileMetaData};
 
 /// Creates a new iterator of compressed pages.
 pub fn get_page_iterator<'b, RR: Read + Seek>(
@@ -161,6 +155,7 @@ fn dict_read<
     }
 }
 
+/// Converts an iterator of [`DataPage`] into a single [`Array`].
 pub fn page_iter_to_array<
     I: StreamingIterator<Item = std::result::Result<DataPage, ParquetError>>,
 >(
@@ -206,10 +201,50 @@ pub fn page_iter_to_array<
 
         Binary | Utf8 => binary::iter_to_array::<i32, _, _>(iter, metadata, &data_type),
         LargeBinary | LargeUtf8 => binary::iter_to_array::<i64, _, _>(iter, metadata, &data_type),
-        FixedSizeBinary(size) => Ok(Box::new(fixed_size_binary::iter_to_array(
+        FixedSizeBinary(_) => Ok(Box::new(fixed_size_binary::iter_to_array(
             iter, data_type, metadata,
         )?)),
-
+        Decimal(_, _) => match metadata.descriptor().type_() {
+            ParquetType::PrimitiveType { physical_type, ..} => match physical_type{
+                PhysicalType::Int32 => primitive::iter_to_array(
+                    iter,
+                    metadata,
+                    data_type,
+                    |x: i32| x as i128,
+                ),
+                PhysicalType::Int64 => primitive::iter_to_array(
+                    iter,
+                    metadata,
+                    data_type,
+                    |x: i64| x as i128,
+                ),
+                PhysicalType::FixedLenByteArray(n) => {
+                    if *n > 16 {
+                        Err(ArrowError::NotYetImplemented(format!(
+                            "Can't decode Decimal128 type from Fixed Size Byte Array of len {:?}",
+                            n
+                        )))
+                    } else {
+                        let paddings = (0..(16-*n)).map(|_| 0u8).collect::<Vec<_>>();
+                        fixed_size_binary::iter_to_array(iter, DataType::FixedSizeBinary(*n), metadata)
+                        .map(|e|{
+                            let a = e.into_iter().map(|v| 
+                                    v.and_then(|v1| {
+                                        [&paddings, v1].concat().try_into().map(
+                                            |pad16| i128::from_be_bytes(pad16)
+                                        ).ok()   
+                                    }
+                                )
+                            ).collect::<Vec<_>>();
+                            Box::new(PrimitiveArray::<i128>::from(a).to(data_type)) as Box<dyn Array>
+                        }
+                        )
+                    }
+                },
+                _ => unreachable!()
+            },
+            _ => unreachable!()
+        },
         List(ref inner) => match inner.data_type() {
             UInt8 => primitive::iter_to_array_nested(iter, metadata, data_type, |x: i32| x as u8),
             UInt16 => primitive::iter_to_array_nested(iter, metadata, data_type, |x: i32| x as u16),
@@ -271,7 +306,7 @@ pub fn page_iter_to_array<
     }
 }
 
-// Converts an async stream of compressed data pages into an [`Array`].
+/// Converts an async stream of [`DataPage`] into a single [`Array`].
 pub async fn page_stream_to_array<I: Stream<Item = std::result::Result<DataPage, ParquetError>>>(
     pages: I,
     metadata: &ColumnChunkMetaData,
@@ -320,7 +355,7 @@ pub async fn page_stream_to_array<I: Stream<Item = std::result::Result<DataPage,
         LargeBinary | LargeUtf8 => {
             binary::stream_to_array::<i64, _, _>(pages, metadata, &data_type).await
         }
-        FixedSizeBinary(size) => Ok(Box::new(
+        FixedSizeBinary(_) => Ok(Box::new(
             fixed_size_binary::stream_to_array(pages, data_type, metadata).await?,
         )),
         other => Err(ArrowError::NotYetImplemented(format!(
